# tests for basic login
import json
import pytest


@pytest.fixture
def tokens(client):
    request_dict = {
        "type": "user",
        "username": "admin",
        "password": "789789"
    }
    request_json = json.dumps(request_dict)
    response = client.post("/api/v1.0/auth/login", data=request_json,
                           headers={"content-type": "application/json"})
    data = json.loads(response.data)
    return data


def test_login_user_valid(client):
    request_dict = {
        "type": "user",
        "username": "admin",
        "password": "789789"
    }
    request_json = json.dumps(request_dict)
    response = client.post("/api/v1.0/auth/login", data=request_json,
                           headers={"content-type": "application/json"})
    assert response.status_code == 200
    assert response.mimetype == "application/json"

    tokens = json.loads(response.data)
    assert tokens.get('access_token')
    assert tokens.get('refresh_token')


# TODO: Add sample components
"""
def test_login_component_valid(client):
    request_dict = {
        "type": "component",
        "name": "test_component",
        "secret": "11123552699"
    }
    request_json = json.dumps(request_dict)
    response = client.post("/api/v1.0/auth/login", data=request_json,
                           headers={"content-type": "application/json"})
    assert response.status_code == 200
    assert response.mimetype == "application/json"
"""


def test_refresh_token(client, tokens: dict):
    headers = {
        "Content-Type": "application/json",
        "Authorization": "Bearer " + tokens['refresh_token']
    }
    response = client.post("/api/v1.0/auth/refresh", headers=headers)
    assert response.status_code == 200
    assert response.mimetype == "application/json"
    assert tokens.get('access_token')


def test_user_logout(client, tokens):
    headers = {
        "Content-Type": "application/json",
        "Authorization": "Bearer " + tokens['access_token']
    }
    response = client.post("/api/v1.0/auth/logout", headers=headers)
    assert response.status_code == 200
    assert response.mimetype == "application/json"





